#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2024-04-24 18:33
# @Author  : Jack
# @File    : __init__.py

"""NStudyPy - A collection of useful Python tools."""

__version__ = "0.0.20"

# 导出公共 API
from . import PyDate
from . import PyEnv
from . import PyFile
from . import PyLogger
from . import PyRe
from . import PyString
from . import PyTools
from . import PyWeb

__all__ = [
    "PyDate",
    "PyEnv",
    "PyFile",
    "PyLogger",
    "PyRe",
    "PyString",
    "PyTools",
    "PyWeb",
]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2025-03-18 11:15
# @Author  : Jack
# @File    : PyLogger

"""
PyLogger
"""
import logging
from logging.handlers import TimedRotatingFileHandler
import os


def get_logger(name=None, logs_dir='logs'):
    """
    获取一个配置好的 logger 实例。
    :param name: logger 名称
    :param logs_dir: 日志文件存放目录
    :return:
    """
    if not os.path.exists(logs_dir):
        os.mkdir(logs_dir)

    if not logging.getLogger().handlers:
        logging.basicConfig(
            level=logging.INFO,
            format='%(asctime)s %(threadName)s %(levelname)s：%(message)s',
            datefmt='%Y-%m-%d %H:%M:%S',
            handlers=[
                logging.StreamHandler(),
                TimedRotatingFileHandler(f'{logs_dir}/app.log', when="midnight", interval=1, backupCount=365, encoding='utf-8')
            ],
        )
    return logging.getLogger(name)


if __name__ == "__main__":
    logger = get_logger(__name__)
    logger.info("Logger is working.")



import pytest
from NStudyPy.PyRe import format_id_card

@pytest.mark.parametrize("input_id, expected", [
    # Valid 15 digit - returns same
    ("350524800101001", "350524800101001"),
    # Valid 18 digit - returns same
    ("35052419800101001X", "35052419800101001X"),
    ("350524198001010014", "350524198001010014"),
    ("35052419800101001x", "35052419800101001x"),
    # Invalid lengths
    ("123", ""),
    ("35052480010100", ""), # 14 digits
    ("3505248001010012", ""), # 16 digits
    ("35052419800101001", ""), # 17 digits
    ("35052419800101001XX", ""), # 19 digits
    # Invalid characters
    ("abcdefghijklmno", ""),
    ("35052419800101001Y", ""), # Y is invalid check digit char
    # Edge cases
    ("", ""),
    (None, ""),  # Ideally the function should handle None or we expect it to fail, but let's see. 
                 # Looking at code: match = _id_card.search(id_card_string). 
                 # re.search throws TypeError on None. The code doesn't check for None.
                 # I will omit None if the function isn't typed to handle it, or expect raise.
                 # Let's stick to string inputs as per signature hint implies string.
])
def test_format_id_card(input_id, expected):
    if input_id is None:
        with pytest.raises(TypeError):
            format_id_card(input_id)
    else:
        assert format_id_card(input_id) == expected



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2024-07-10 15:27
# @Author  : Jack
# @File    : PyRe

"""
PyRe
"""
import re

# 身份证号
_id_card = re.compile(r'(^\d{15}$)|(^\d{17}[\dXx]$)')


def format_id_card(id_card_string):
    """
    格式化身份证号码
    :param id_card_string:
    :return:
    """
    match = _id_card.search(id_card_string)
    if match:
        old_id_card, id_card = match.groups()
        return id_card or old_id_card
    else:
        return ""
